@@ -1,7 +1,7 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '1.15';
+our $VERSION = '1.16';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
@@ -328,15 +328,13 @@ sub _colgroup {
 
 sub _tag {
     my %args = @_;
-    my $tag;
-    my $value = $args{ $args{tag} };
-    if (ref $value eq 'HASH') {
-        (my $cdata) = keys %$value;
-        (my $attr)  = values %$value;
-        $tag = { tag => $args{tag}, attr => $attr, cdata => $cdata };
-    } elsif (defined $args{ $args{tag} } ) {
-        $tag = { tag => $args{tag}, cdata => $value };
-    } 
+    my $thingy = $args{ $args{tag} };
+    return unless defined $thingy;
+    my $tag = { tag => $args{tag}, cdata => $thingy };
+    if (ref $thingy eq 'HASH') {
+        $tag->{cdata} = ( keys   %$thingy )[0];
+        $tag->{attr}  = ( values %$thingy )[0];
+    }
     return $tag;
 }
 
@@ -509,8 +507,8 @@ and C<landscape> (headings at left) are all you need.
 
 All methods/procedures accept the same named parameters. Some methods
 pre-define parameters on your behalf, for convenience. If these parameters
-are defined, they may be overriden. You do not necessarily have
-to specify C<data>, any bare array references will be collected
+are defined, they may be overriden where applicable. You do not necessarily
+have to specify C<data>, any bare array references will be collected
 and assigned to C<data>. Just because you can, however, does not
 mean you should. Everything is meant to be convenient.
 
@@ -563,8 +561,8 @@ Representing an image as an HTML table on a pixel by pixel basis
 tends to produce tables that are too large. This parameter can be
 used to increase and decrease that size, by reading in blocks of
 pixels (8x8=64 pixels to be represented by one table cell) and
-determines the pixel color for that block. The smaller the
-block size the longer the processing time.
+determining the pixel color for that block (see C<blend> below).
+The smaller the block size the longer the processing time.
 
   block => 4
 
@@ -572,9 +570,9 @@ block size the longer the processing time.
 
 Boolean. Default false. Can be supplied in conjuction with C<block>
 to change the algorithm for determining block's pixel color. When
-set to true, the pixel color is determined by the average color of
+set to true, the pixel color is determined by averaging the colors of
 all pixels in that block. When false (default), the pixel color is
-determined by finding the the most use color in the block.
+determined by finding the the most used color in the block.
 
   blend => 1
 
@@ -584,10 +582,10 @@ off for producing 1980's style pixel art images.
 =item * C<worksheet>
 
 Integer. Can be supplied in conjunction with C<file>. If multiple
-worksheets or data tables are present, use this parameter to select
-which one (index 1 based). Defaults to 1 (first found).
+worksheets or data tables (or image frames) are present, use this
+parameter to select which one (index 1 based). Defaults to 1 (first found).
 
-  worksheet => 3 # the third data table or worksheet found  
+  worksheet => 3 # the third worksheet, data table or image frame found  
 
 =item * C<preserve>
 
@@ -1152,7 +1150,7 @@ Jeff Anderson, C<< <jeffa at cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2015 Jeff Anderson.
+Copyright 2016 Jeff Anderson.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
